@@ -23,11 +23,11 @@
 //!        interactively, by prompting the user for the inputs needed)
 //!     * `issue (open|view|browse)` -- open issue's URL in browser
 //!     * `issue (show|info|get)` -- show details about a issue
+//!     * `issue list` -- get list of issues
 //!
 //! ## Planned functions
 //!
 //!  * `project list` -- get list of projects
-//!  * `issue list` -- get list of issues
 //!  * `merge-request` -- interact with merge requests
 //!  * `pipeline` -- interact with Gitlab CI jobs
 //!  * `group` -- interact with Gitlab groups
@@ -115,16 +115,16 @@ fn main() -> Result<()> {
     //TODO: refactor this at some point...
     let cli_commands = subcommand::ClapCommands {
         commands: vec![
-            Box::new(init::Init {
+            Box::new(init::InitCmd {
                 clap_cmd: clap::SubCommand::with_name("init"),
             }),
-            Box::new(merge_request::MergeRequest {
+            Box::new(merge_request::MergeRequestCmd {
                 clap_cmd: clap::SubCommand::with_name("merge-request"),
             }),
-            Box::new(issue::Issue {
+            Box::new(issue::IssueCmd {
                 clap_cmd: clap::SubCommand::with_name("issue"),
             }),
-            Box::new(project::Project {
+            Box::new(project::ProjectCmd {
                 clap_cmd: clap::SubCommand::with_name("project"),
             }),
         ],
